@@ -8,8 +8,6 @@ import json
 import traceback
 import sys
 from .src.cusFuns.core.FunsPool import auto_register
-from .src.core.Versions import VersionManager
-
 from .src.helper.utils import json_converter
 from .src.dataModel.pandasCmd import PandasCmd
 from .src.core.Proxy import ProxyManager
@@ -48,8 +46,10 @@ def get_data_from_post():
 
 @app.route('/')
 def index():
+    from . import __version__
     # return flask.render_template('index.html')
-    return f'版本号：{VersionManager.m_current_version}'
+    pd.DataFrame({'a': [1, 2, 3]}).to_csv('test_ret.csv')
+    return f'版本号：{__version__}'
 
 
 @app.route('/api/get_file_args/ext=<ext>', methods=['get'])
@@ -235,14 +235,14 @@ def find_arg(args, flag, return_value=True):
     return False, None
 
 
-def start_update():
+# def start_update():
 
-    try:
-        import pdcoder_start_update
-    except ImportError:
-        return
-    os.system(f'start pdcoder_start_update -dir {os.getcwd()}')
-    sys.exit()
+#     try:
+#         import pdcoder_start_update
+#     except ImportError:
+#         return
+#     os.system(f'start pdcoder_start_update -dir {os.getcwd()}')
+#     sys.exit()
 
 
 def main():
@@ -252,9 +252,9 @@ def main():
     if has:
         os.chdir(dir)
 
-    has, _ = find_arg(args, '-u', return_value=False)
-    if has:
-        start_update()
+    # has, _ = find_arg(args, '-u', return_value=False)
+    # if has:
+    #     start_update()
 
     run()
 
